/***************************************************************************
 * Copyright 2013 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.web.beans.view;

import java.util.Collections;
import java.util.List;

import javax.annotation.PostConstruct;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import kieker.webgui.web.beans.application.ProjectsBean;

import org.primefaces.event.SelectEvent;

/**
 * The {@link CurrentProjectOverviewBean} contains the necessary data behind an instance of the project overview.<br>
 * The class is a Spring managed bean with view scope.
 * 
 * @author Nils Christian Ehmke
 */
@Component
@Scope("view")
public final class CurrentProjectOverviewBean {

	@Autowired
	private ProjectsBean projectsBean;
	private List<String> projects = Collections.emptyList();
	private String projectName;

	/**
	 * Default constructor. <b>Do not call this constructor manually. It will only be accessed by Spring.</b>
	 */
	public CurrentProjectOverviewBean() {
		// No code necessary
	}

	public String getProjectName() {
		return this.projectName;
	}

	public void setProjectName(final String projectName) {
		this.projectName = projectName;
	}

	/**
	 * This is the event listener used to select a row instantaneously.
	 * 
	 * @param event
	 *            The select event.
	 */
	public void onRowSelect(final SelectEvent event) {
		this.setProjectName((String) event.getObject());
	}

	public void setProjectsBean(final ProjectsBean projectsBean) {
		this.projectsBean = projectsBean;
	}

	public List<String> getProjects() {
		return this.projects;
	}

	/**
	 * This method should only be called automatically by Spring to update the projects list.
	 */
	@PostConstruct
	protected void initialialize() {
		this.updateLists();
	}

	/**
	 * Updates the list containing the available projects name.
	 */
	public void updateLists() {
		this.projects = this.projectsBean.getProjects();
	}

}
