/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.web.converter;

import org.junit.Assert;
import org.junit.Test;

import kieker.webgui.domain.User.Role;

/**
 * Test class for {@link RoleStringConverter}.
 * 
 * @author Nils Christian Ehmke
 */
public class RoleStringConverterTest {

	/**
	 * Default constructor. <b>Do not use this constructor. This is just a test class and not to be used outside a JUnit test!</b>
	 */
	public RoleStringConverterTest() {
		// No code necessary
	}

	/**
	 * A test of this test class.
	 */
	@Test
	public void testEqualAsString() {
		final RoleStringConverter converter = new RoleStringConverter();

		Assert.assertEquals("Conversion failed.", Role.ROLE_ADMIN.toString(), converter.getAsString(null, null, Role.ROLE_ADMIN));
		Assert.assertEquals("Conversion failed.", Role.ROLE_GUEST.toString(), converter.getAsString(null, null, Role.ROLE_GUEST));
		Assert.assertEquals("Conversion failed.", Role.ROLE_USER.toString(), converter.getAsString(null, null, Role.ROLE_USER));
	}

	/**
	 * A test of this test class.
	 */
	@Test
	public void testNotEqualAsString() {
		final RoleStringConverter converter = new RoleStringConverter();

		Assert.assertNotSame("Conversion failed.", Role.ROLE_ADMIN, converter.getAsString(null, null, Role.ROLE_USER));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_ADMIN, converter.getAsString(null, null, Role.ROLE_GUEST));

		Assert.assertNotSame("Conversion failed.", Role.ROLE_GUEST, converter.getAsString(null, null, Role.ROLE_ADMIN));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_GUEST, converter.getAsString(null, null, Role.ROLE_USER));

		Assert.assertNotSame("Conversion failed.", Role.ROLE_USER, converter.getAsString(null, null, Role.ROLE_GUEST));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_USER, converter.getAsString(null, null, Role.ROLE_ADMIN));
	}

	/**
	 * A test of this test class.
	 */
	@Test
	public void testEqualFromString() {
		final RoleStringConverter converter = new RoleStringConverter();

		Assert.assertEquals("Conversion failed.", Role.ROLE_ADMIN, converter.getAsObject(null, null, Role.ROLE_ADMIN.toString()));
		Assert.assertEquals("Conversion failed.", Role.ROLE_GUEST, converter.getAsObject(null, null, Role.ROLE_GUEST.toString()));
		Assert.assertEquals("Conversion failed.", Role.ROLE_USER, converter.getAsObject(null, null, Role.ROLE_USER.toString()));
	}

	/**
	 * A test of this test class.
	 */
	@Test
	public void testNotEqualFromString() {
		final RoleStringConverter converter = new RoleStringConverter();

		Assert.assertNotSame("Conversion failed.", Role.ROLE_ADMIN, converter.getAsObject(null, null, Role.ROLE_USER.toString()));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_ADMIN, converter.getAsObject(null, null, Role.ROLE_GUEST.toString()));

		Assert.assertNotSame("Conversion failed.", Role.ROLE_GUEST, converter.getAsObject(null, null, Role.ROLE_ADMIN.toString()));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_GUEST, converter.getAsObject(null, null, Role.ROLE_USER.toString()));

		Assert.assertNotSame("Conversion failed.", Role.ROLE_USER, converter.getAsObject(null, null, Role.ROLE_GUEST.toString()));
		Assert.assertNotSame("Conversion failed.", Role.ROLE_USER, converter.getAsObject(null, null, Role.ROLE_ADMIN.toString()));
	}
}
